==> download.php?FileName=terralib-5.3.0.zip: src/terralib/qt/widgets/canvas/GridPropertyWidget.cpp <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

This file is part of the TerraLib - a Framework for building GIS enabled applications.

TerraLib is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

TerraLib is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with TerraLib. See COPYING. If not, write to
TerraLib Team at <terralib-team@terralib.org>.
*/

/*!
 * \file widgets/canvas/GridPropertyWidget.cpp
 */

#include "GridPropertyWidget.h"
#include "Grid.h"

// TerraLib
#include "../propertybrowser/AbstractPropertyManager.h"

// Qt
#include <QLayout>


te::qt::widgets::GridPropertyWidget::GridPropertyWidget(Grid* wid, QWidget* parent) :
  QDockWidget(parent)
{
  QWidget* w = new QWidget(this);

  QtTreePropertyBrowser* pb = new QtTreePropertyBrowser(w);
  pb->setPropertiesWithoutValueMarked(true);
  pb->setResizeMode(QtTreePropertyBrowser::ResizeToContents);

  new GridPropertyBrowser(pb, wid);

  QGridLayout* lay = new QGridLayout(w);
  lay->addWidget(pb);

  setWidget(w);

  connect(wid, SIGNAL(aboutToBeclosed()), SLOT(gridClosed()));
}

te::qt::widgets::GridPropertyWidget::~GridPropertyWidget()
{

}

void te::qt::widgets::GridPropertyWidget::gridClosed()
{
  close();
}

te::qt::widgets::GridPropertyBrowser::GridPropertyBrowser(QtTreePropertyBrowser* pb, Grid* wid) :
  te::qt::widgets::AbstractPropertyItem(pb)
{
  QStringList types_names;

  types_names <<tr("Planar Grid")
             <<tr("Geographic Grid");

  QtProperty* grid_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_groupManager->addProperty(tr("Grid properties"));

  // font
  QtProperty* font_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->addProperty(tr("Font"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->setValue(font_prop, wid->getFont());
  grid_prop->addSubProperty(font_prop);

  // color
  QtProperty* color_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->addProperty(tr("Color"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->setValue(color_prop, wid->getColor());
  grid_prop->addSubProperty(color_prop);

  // scale type
  QtProperty* type_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->addProperty(tr("Grid type"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setEnumNames(type_prop, types_names);
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setValue(type_prop, wid->getType());
  grid_prop->addSubProperty(type_prop);
  // ===================

  addProperty(grid_prop, tr("Grid"), QColor(175, 255, 175));

  wid->connect(this, SIGNAL(colorChanged(const QColor&)), SLOT(setColor(const QColor&)));
  wid->connect(this, SIGNAL(fontChanged(const QFont&)), SLOT(setFont(const QFont&)));
  wid->connect(this, SIGNAL(gridTypeChanged(const int&)), SLOT(setGridType(const int&)));
}

te::qt::widgets::GridPropertyBrowser::~GridPropertyBrowser()
{
}

void te::qt::widgets::GridPropertyBrowser::valueChanged(QtProperty*, const QColor& value)
{
  emit colorChanged(value);
}

void te::qt::widgets::GridPropertyBrowser::valueChanged(QtProperty*, const QFont& value)
{
  emit fontChanged(value);
}

void te::qt::widgets::GridPropertyBrowser::valueChanged(QtProperty*, int value)
{
  emit gridTypeChanged(value);
}

==> download.php?FileName=terralib-5.3.2.zip: src/terralib/qt/widgets/canvas/GridPropertyWidget.cpp <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

This file is part of the TerraLib - a Framework for building GIS enabled applications.

TerraLib is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

TerraLib is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with TerraLib. See COPYING. If not, write to
TerraLib Team at <terralib-team@terralib.org>.
*/

/*!
 * \file widgets/canvas/GridPropertyWidget.cpp
 */

#include "GridPropertyWidget.h"
#include "Grid.h"

// TerraLib
#include "../propertybrowser/AbstractPropertyManager.h"

// Qt
#include <QAction>
#include <QLayout>


te::qt::widgets::GridPropertyWidget::GridPropertyWidget(Grid* wid, QAction* editAction) :
  QDockWidget(0),
  m_editAction(editAction),
  m_gridStatus(true)
{
  QWidget* w = new QWidget(this);

  QtTreePropertyBrowser* pb = new QtTreePropertyBrowser(w);
  pb->setPropertiesWithoutValueMarked(true);
  pb->setResizeMode(QtTreePropertyBrowser::ResizeToContents);

  new GridPropertyBrowser(pb, wid);

  QGridLayout* lay = new QGridLayout(w);
  lay->addWidget(pb);

  setWidget(w);

  connect(wid, SIGNAL(aboutToBeclosed()), SLOT(gridClosed()));

  m_editAction->setEnabled(false);

  setAttribute(Qt::WA_DeleteOnClose, true);
}

te::qt::widgets::GridPropertyWidget::~GridPropertyWidget()
{
  m_editAction->setEnabled(m_gridStatus);
}

void te::qt::widgets::GridPropertyWidget::gridClosed()
{
  m_gridStatus = false;
  close();
}

te::qt::widgets::GridPropertyBrowser::GridPropertyBrowser(QtTreePropertyBrowser* pb, Grid* wid) :
  te::qt::widgets::AbstractPropertyItem(pb)
{
  QStringList types_names;

  types_names <<tr("Planar Grid")
             <<tr("Geographic Grid");

  QtProperty* grid_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_groupManager->addProperty(tr("Grid properties"));

  // font
  QtProperty* font_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->addProperty(tr("Font"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_fontManager->setValue(font_prop, wid->getFont());
  grid_prop->addSubProperty(font_prop);

  // color
  QtProperty* color_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->addProperty(tr("Color"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_colorManager->setValue(color_prop, wid->getColor());
  grid_prop->addSubProperty(color_prop);

  // scale type
  QtProperty* type_prop = te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->addProperty(tr("Grid type"));
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setEnumNames(type_prop, types_names);
  te::qt::widgets::AbstractPropertyManager::getInstance().m_enumManager->setValue(type_prop, wid->getType());
  grid_prop->addSubProperty(type_prop);
  // ===================

  addProperty(grid_prop, tr("Grid"), QColor(175, 255, 175));

  wid->connect(this, SIGNAL(colorChanged(const QColor&)), SLOT(setColor(const QColor&)));
  wid->connect(this, SIGNAL(fontChanged(const QFont&)), SLOT(setFont(const QFont&)));
  wid->connect(this, SIGNAL(gridTypeChanged(const int&)), SLOT(setGridType(const int&)));
}

te::qt::widgets::GridPropertyBrowser::~GridPropertyBrowser()
{
}

void te::qt::widgets::GridPropertyBrowser::valueChanged(QtProperty*, const QColor& value)
{
  emit colorChanged(value);
}

void te::qt::widgets::GridPropertyBrowser::valueChanged(QtProperty*, const QFont& value)
{
  emit fontChanged(value);
}

void te::qt::widgets::GridPropertyBrowser::valueChanged(QtProperty*, int value)
{
  emit gridTypeChanged(value);
}
